package main

import (
	"fmt"
	"io"
	"os"
	"remote-mic/audio"
	"remote-mic/connection"
	"time"
)


func pulsectlExample() {
	pulsectl := audio.NewPulsectl()
	err := pulsectl.LoadPipeSourceModule()
	if err != nil {
		panic(err)
	}
	time.Sleep(10 * time.Second)
	pulsectl.UnloadPipeSourceModule()
}

func micStreamExample() {
	mic, err := audio.NewMicrophone()
	if err != nil {
		panic(err)
	}
	err = mic.Start()
	if err != nil {
		panic(err)
	}
	defer mic.Stop()

	for {
		io.Copy(os.Stdout, mic.AudioStream())
	}
}

func usage() {
	fmt.Println("Usage: remote-mic <command>")
	os.Exit(1)
}

func listen() {
	fmt.Print("Listening for connection on port 8080... ")
	conn, err := connection.NewListen(":8080")
	if err != nil {
		panic(err)
	}
	fmt.Println("Connection accepted!")

	recvChan := conn.RecvChan()
	for {
		buf, open := <-recvChan
		if !open {
			break
		}
		fmt.Printf("Bytes read: %d\n", len(buf))
		fmt.Printf("Buf: %v\n", buf)
		fmt.Printf("%v\n", string(buf))		
	}
}

func stream() {
	conn2, err := connection.NewConnect("localhost:8080")
	if err != nil {
		fmt.Println(err)
		panic(err)
	}

	c := conn2.SendChan()
	c <- []byte("cicasajtok")

	time.Sleep(20 * time.Second)
	fmt.Println("Exiting.")
}

func main() {
	if len(os.Args) < 2 {
		usage()
	}
	cmd := os.Args[1]

	switch cmd {
	case "listen":
		listen()
	case "stream":
		stream()
	default:
		usage()
	}
}
